<?php

namespace Tests\Feature;

use App\Models\User;
use Laravel\Sanctum\Sanctum;
use Tests\TestCase;

class UserDetailTest extends TestCase
{
    public function test_success_access_to_users_details_by_admin()
    {
        $user = User::factory()->create([
            'role' => 'admin',
        ]);
        $userDetails = User::factory()->create([
            'role' => 'common',
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->get('/nova/resources/users/' . $userDetails->id);
        $user->delete();
        $userDetails->delete();
        $response->assertStatus(200);
    }

    public function test_success_access_to_users_details_by_analyst()
    {
        $user = User::factory()->create([
            'role' => 'analyst',
        ]);
        $userDetails = User::factory()->create([
            'role' => 'common',
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->get('/nova/resources/users/' . $userDetails->id);
        $user->delete();
        $userDetails->delete();
        $response->assertStatus(200);
    }

    public function test_access_to_users_details_by_common()
    {
        $user = User::factory()->create([
            'role' => 'common',
        ]);
        $userDetails = User::factory()->create([
            'role' => 'common',
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->get('/nova/resources/users/' . $userDetails->id);
        $user->delete();
        $userDetails->delete();
        $response->assertStatus(403);
    }

    public function test_access_to_users_details_by_unauthorized()
    {
        $userDetails = User::factory()->create([
            'role' => 'common',
        ]);
        $response = $this->get('/nova/resources/users/' . $userDetails->id);
        $userDetails->delete();
        $response->assertStatus(302);
    }
}
